@@ -270,7 +270,7 @@ sp.to.fe <-  function(sp_tr, tr_cat, fe_nm_type = "fe_rank",
       u_val_k <- as.character(unique(val_k_df$E))
       # add code of fuzzy entities to barcode of all traits: ...
       # ... get all combinations of traits to draw FEs:
-      sp_fbarcode <- paste(sp_fbarcode, u_val_k, sep = "_")
+      sp_fbarcode <- paste(sp_fbarcode, val_k, sep = "_")
       # there are variable values for each fuzzy entity so ...
       # ... pick values from first species belonging to the fuzzy entity...
       # ... so we can get all combinations of "traits" forming ...
